@@ -34,6 +34,7 @@ class HistoryDownload:
         self.all_symbols = None
 
     def init(self):
+        print(self.type)
         if self.all_symbols is None:
             ok, all_symbols = False, []
             if self.type == _SPOT:
@@ -49,11 +50,11 @@ class HistoryDownload:
 
             if not ok:
                 logger.warning(all_symbols)
+
                 return
             self.all_symbols = all_symbols
 
     def _download_daily(self, path_url, symbol, period) -> tuple:
-        
         all_oks = []
         all_errs = []
         interval = self.end_date - self.start_date
@@ -75,10 +76,10 @@ class HistoryDownload:
                 all_oks.append(url)
         return all_oks, all_errs
 
-    def b_download(self, all_symbols: list = None):
+    def b_download(self):
         """return date is: [start, end)"""
         self.init()
-        for symbol in all_symbols:
+        for symbol in self.all_symbols:
             for period in self.all_period:
                 if period in ['trades', ]:
                     path_url = f'{self.pre_url}/{self.data_type}/{self.type}/{self.freq}/{symbol}'
@@ -89,30 +90,30 @@ class HistoryDownload:
                 logger.warning(f'failed:{all_errs}')
         logger.info('done')
 
-    def b_download_daily_spot(self, all_symbols: list = None):
+    def b_download_daily_spot(self):
         """return date is: [start, end)"""
         self.type = _SPOT
-        self.b_download(all_symbols)
+        self.b_download()
 
-    def b_download_daily_future(self, all_symbols: list = None):
+    def b_download_daily_future(self):
         """return date is: [start, end)"""
         self.type = _FUTURE
-        self.b_download(all_symbols)
+        self.b_download()
 
-    def b_download_daily_swap(self, all_symbols: list = None):
+    def b_download_daily_swap(self):
         """return date is: [start, end)"""
         self.type = _SWAP
-        self.b_download(all_symbols)
+        self.b_download()
 
-    def b_download_daily_linearswap(self, all_symbols: list = None):
+    def b_download_daily_linearswap(self):
         """return date is: [start, end)"""
         self.type = _LINEARSWAP
-        self.b_download(all_symbols)
+        self.b_download()
 
-    def b_download_daily_option(self, all_symbols: list = None):
+    def b_download_daily_option(self):
         """return date is: [start, end)"""
         self.type = _OPTION
-        self.b_download(all_symbols)
+        self.b_download()
 
 
 if __name__ == "__main__":
